.. _api_reference:

API Reference
=============

This section provides a high-level API reference for the Intellibricks library. For detailed information on specific classes and functions, please refer to the module documentation.

.. toctree::
   :maxdepth: 1

   intellibricks.agents
   intellibricks.llms
   intellibricks.rag
